package beilv.system.mapper;



import beilv.system.domain.SysMember;

import java.util.List;

/**
 * 会员用户信息Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-02
 */
public interface SysMemberMapper {
    /**
     * 查询会员用户信息
     *
     * @param id 会员用户信息主键
     * @return 会员用户信息
     */
    public SysMember selectSysMemberById(Long id);

    /**
     * 查询会员用户信息列表
     *
     * @param sysMember 会员用户信息
     * @return 会员用户信息集合
     */
    public List<SysMember> selectSysMemberList(SysMember sysMember);

    /**
     * 新增会员用户信息
     *
     * @param sysMember 会员用户信息
     * @return 结果
     */
    public int insertSysMember(SysMember sysMember);

    /**
     * 修改会员用户信息
     *
     * @param sysMember 会员用户信息
     * @return 结果
     */
    public int updateSysMember(SysMember sysMember);

    /**
     * 删除会员用户信息
     *
     * @param id 会员用户信息主键
     * @return 结果
     */
    public int deleteSysMemberById(Long id);

    /**
     * 批量删除会员用户信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysMemberByIds(String[] ids);

    SysMember selectByMobile(String openId);

    public int createUserIfAbsent(SysMember memberUserDO);
}
